@@ -206,7 +206,7 @@ fn test_expand_sub_rust_macro() {
 
 #[path = "strnom.rs"]
 mod strnom;
-use strnom::*;
+use crate::strnom::*;
 
 fn skip_literal(mut input: Cursor) -> PResult<bool> {
     //input = whitespace(input)?.0;
@@ -271,11 +271,10 @@ fn test_skip_literal() -> Result<(), LexError> {
 
     assert!((skip_whitespace(new_cursor("ok xx"))).starts_with("ok"));
     assert!((skip_whitespace(new_cursor("   ok xx"))).starts_with("ok"));
-    assert!(
-        (skip_whitespace(new_cursor(
-            " \n /*  /*dd \n // */ */ // foo \n    ok xx/* */"
-        ))).starts_with("ok")
-    );
+    assert!((skip_whitespace(new_cursor(
+        " \n /*  /*dd \n // */ */ // foo \n    ok xx/* */"
+    )))
+    .starts_with("ok"));
 
     Ok(())
 }
@@ -509,10 +508,12 @@ impl Parser {
         match ::syn::parse2::<Macro>(input).map_err(|e| LineError(x.line, e.to_string()))? {
             Macro::Closure(mut c) => {
                 c.callback_offset = self.callbacks_count;
-                c.body_str = line_directive(&self.current_path, begin) + &expand_sub_rust_macro(
-                    extracted.to_string(),
-                    ExpandSubMacroType::Closure(&mut self.callbacks_count),
-                ).map_err(|e| e.add_line(begin.line))?;
+                c.body_str = line_directive(&self.current_path, begin)
+                    + &expand_sub_rust_macro(
+                        extracted.to_string(),
+                        ExpandSubMacroType::Closure(&mut self.callbacks_count),
+                    )
+                    .map_err(|e| e.add_line(begin.line))?;
                 self.closures.push(c);
             }
             Macro::Lit(_l) => {
@@ -520,7 +521,8 @@ impl Parser {
                 let snip = expand_sub_rust_macro(
                     line_directive(&self.current_path, begin) + extracted,
                     ExpandSubMacroType::Lit,
-                ).map_err(|e| e.add_line(begin.line))?;
+                )
+                .map_err(|e| e.add_line(begin.line))?;
                 self.snippets.push_str(&snip);
             }
         }
@@ -571,38 +573,33 @@ impl<'ast> Visit<'ast> for Parser {
 
         // Determine the path of the inner module's file
         for attr in &item.attrs {
-            match attr.interpret_meta() {
+            match attr.parse_meta() {
                 // parse #[path = "foo.rs"]: read module from the specified path
-                Some(syn::Meta::NameValue(syn::MetaNameValue {
-                    ident: ref id,
+                Ok(syn::Meta::NameValue(syn::MetaNameValue {
+                    ref path,
                     lit: syn::Lit::Str(ref s),
                     ..
-                }))
-                    if id == "path" =>
-                {
+                })) if path.is_ident("path") => {
                     let mod_path = self.mod_dir.join(&s.value());
                     return self
                         .parse_mod(mod_path)
                         .unwrap_or_else(|err| self.mod_error = Some(err));
-                },
+                }
                 // parse #[cfg(feature = "feature")]: don't follow modules not enabled by current features
-                Some(syn::Meta::List(syn::MetaList {
-                    ident: ref id,
-                    nested: ref nesteds,
+                Ok(syn::Meta::List(syn::MetaList {
+                    ref path,
+                    ref nested,
                     ..
-                }))
-                    if id == "cfg" =>
-                {
-                    for nested in nesteds {
-                        match nested {
+                })) if path.is_ident("cfg") => {
+                    for n in nested {
+                        match n {
                             syn::NestedMeta::Meta(syn::Meta::NameValue(syn::MetaNameValue {
-                                ident: cfg_id,
+                                path,
                                 lit: syn::Lit::Str(feature),
                                 ..
-                            }))
-                                if cfg_id == "feature" =>
-                            {
-                                let feature_env_var = "CARGO_FEATURE_".to_owned() + &feature.value().to_uppercase().replace("-", "_");
+                            })) if path.is_ident("feature") => {
+                                let feature_env_var = "CARGO_FEATURE_".to_owned()
+                                    + &feature.value().to_uppercase().replace("-", "_");
                                 if std::env::var_os(feature_env_var).is_none() {
                                     return;
                                 }
@@ -610,7 +607,7 @@ impl<'ast> Visit<'ast> for Parser {
                             _ => {}
                         }
                     }
-                },
+                }
                 _ => {}
             }
         }
